@@ -60,7 +60,7 @@ class Rt:
               expected as input for string values.
     """
 
-    def __init__(self, url, default_login=None, default_password=None):
+    def __init__(self, url, default_login=None, default_password=None, proxy=None):
         """ API initialization.
         
         :keyword url: Base URL for Request Tracker API.
@@ -68,11 +68,17 @@ class Rt:
         :keyword default_login: Default RT login used by self.login if no
                                 other credentials are provided
         :keyword default_password: Default RT password
+        :keyword proxy: Proxy server (string with http://user:password@host/ syntax)
         """
         self.url = url
         self.default_login = default_login
         self.default_password = default_password
-        self.session = requests.session()
+        if proxy is not None:
+            if url.lower().startswith("https://"):
+                proxy = {"https": proxy}
+            else:
+                proxy = {"http": proxy}
+        self.session = requests.session(proxies=proxy)
         self.login_result = None
 
     def __request(self, selector, post_data={}, files=[], without_login=False):
@@ -557,6 +563,17 @@ Bcc: %s"""%(str(ticket_id), re.sub(r'\n', r'\n      ', text), cc, bcc)}
                   second line starts with the same indentation as first
             Attachment: an attachment filename/path
 
+        Example::
+            
+            >>> tracker = Rt('http://tracker.example.com/REST/1.0/', 'rt-username', 'top-secret')
+            >>> attachment_name = sys.argv[1]
+            >>> message_text = ' '.join(sys.argv[2:])
+            >>> ret = tracker.comment(ticket_id, text=message_text,
+            ... files=[(attachment_name, open(attachment_name, 'rb'))])
+            >>> if not ret:
+            ...     print('Error: could not send attachment', file=sys.stderr)
+            ...     exit(1)
+
         :param ticket_id: ID of ticket to which comment belongs
         :keyword text: Content of comment
         :keyword files: List of pairs (filename, file-like object) describing
@@ -782,7 +799,7 @@ Text: %s""" % (str(ticket_id), re.sub(r'\n', r'\n      ', text))}
         """ Gets the ticket links for a single ticket.
         
         :param ticket_id: ticket ID
-        :returns: Links as strings in dictionary with these keys
+        :returns: Links as lists of strings in dictionary with these keys
                   (just those which are defined):
 
                       * id
@@ -800,10 +817,22 @@ Text: %s""" % (str(ticket_id), re.sub(r'\n', r'\n      ', text))}
         if(self.__get_status_code(msg) == 200):
             pairs = {}
             msg = msg.split('\n')[2:]
-            for i in range(len(msg)):
+            i = 0
+            while i < len(msg):
                 colon = msg[i].find(': ')
                 if colon > 0:
-                    pairs[msg[i][:colon].strip()] = msg[i][colon + 1:].strip()
+                    key = msg[i][:colon]
+                    links = [msg[i][colon + 1:].strip()]
+                    j = i + 1
+                    pad = len(key) + 2
+                    # loop over next lines for the same key 
+                    while (j < len(msg)) and msg[j].startswith(' ' * pad):
+                        links[-1] = links[-1][:-1] # remove trailing comma from previous item
+                        links.append(msg[j][pad:].strip())
+                        j += 1
+                    pairs[key] = links
+                    i = j - 1
+                i += 1
             return pairs
         else:
             raise Exception('Connection error')
